# $NetBSD: web.xml.mk,v 1.6 2006/07/31 11:39:04 rillig Exp $
#

# This file is included by web.site.mk, so you should not include it
# yourself. It provides a method for converting XML files in the DocBook
# webpage format into HTML documents.
#
# The following variables may be set in htdocs Makefiles:
#
# XMLDOCS:
#	A list of XML document identifiers, which are usually the same
#	as the basename of the XML document.
#
#	Alternatively, such an identifier can be of the form
#	"docid:stylesheet:xml:target". This is syntactic sugar for
#	setting XSLT.<docid>, XML.<docid> and TARGET.<docid>. If any of
#	the components is left empty, the default value (see below) is
#	used.
#
#	Examples:
#	XMLDOCS+=	doc1
#	XMLDOCS+=	packages:pkgsrc-home.xsl::
#
# TARGET.<id>:
#	The target filename. The default value is <id>.html.
#
#	Example:
#	TARGET.doc1=	document1.html
#
# XSLT.<id>:
#	Filename of the XSLT stylesheet. The default value is <id>.xsl.
#	The following keywords are interpreted specially:
#
#		docbook		- Norm Walsh's DocBook stylesheet
#		docbook-website	- Norm Walsh's Website stylesheet
#		xsl		- <id>.xsl
#
#	Example:
#	XSLT.doc1=	doc1.xsl
#
# XML.<id>:
#	Filename of the XML document. The default value is <id>.xml.
#	FIXME: Better explain this.
#
#	Example:
#	XML.doc1=	doc1.xml data.xml
#
# DEPENDS.<id>:
#	Additional dependencies. The default value is the empty list.
#
#	Example:
#	DEPENDS.doc1=	includes.xsl
#
# PARAMS.<id>:
#	Arguments passed to xsltproc(1).
#
#	Examples:
#	PARAMS.doc1=	--catalogs --nonet --xinclude
#	PARAMS.doc1=	--stringparam WEB_PREFIX ${WEB_PREFIX}
#
# XSLTPROCOPTS.<id>:
#	Arguments passed to xsltproc(1) instead of the default
#	arguments.
#
#	No example available.
#
# XSLTPROC_ARGS:
#	Arguments passed to all invocations of xsltproc(1).
#
#	Examples:
#	XSLTPROC_ARGS+=	--stringparam l10n.gentext.language de
#

XSLTPROC_ENV+=	SGML_CATALOG_FILES=
XSLTPROC_ENV+=	XML_CATALOG_FILES="${XML_CATALOG_FILES}"

XSLTPROCOPTS=	${XSLTPROC_ARGS}
XSLTPROCOPTS+=	--xinclude
XSLTPROCOPTS+=	--stringparam LOCALBASE ${LOCALBASE}
XSLTPROCOPTS+=	--stringparam WEB_PREFIX ${WEB_PREFIX}
.if defined(XML_CATALOG_FILES) && !empty(XML_CATALOG_FILES)
XSLTPROCOPTS+= --nonet --catalogs
.endif
XSLTPROC=	env ${XSLTPROC_ENV} ${PREFIX}/bin/xsltproc

XMLLINTOPTS+=	--xinclude --valid --noout
.if defined(XML_CATALOG_FILES) && !empty(XML_CATALOG_FILES)
XMLLINTOPTS+=	--nonet --catalogs
.endif
XMLLINT=	env ${XSLTPROC_ENV} ${PREFIX}/bin/xmllint

XSLT.DEFAULT?=	docbook-website

.for D in ${XMLDOCS}
# use temporary variable because "make" in NetBSD 1.6.x cannot evaluate
# the modifier of a .for-variable in a conditional)
_tmpD=${D}

# extract docid from "docid:xslt:xml:target".
.  for _ID in ${_tmpD:C,:.*$,,}

.    if ${_tmpD:C,[^:],,g} == ":::"
XSLT.${_ID}=	${D:C,^([^:]*):([^:]*):([^:]*):([^:]*)$,\2,}
XML.${_ID}=	${D:C,^([^:]*):([^:]*):([^:]*):([^:]*)$,\3,}
TARGET.${_ID}=	${D:C,^([^:]*):([^:]*):([^:]*):([^:]*)$,\4,}
.    elif ${_tmpD:C,[^:],,g} != ""
ERRORS+=	"[web.xml.mk] XMLDOCS.${_ID} must have exactly four components."
.    endif

# Use default value if parameter not specified or empty.
.    if !defined(XSLT.${_ID}) || empty(XSLT.${_ID})
XSLT.${_ID}=	${XSLT.DEFAULT}
.    endif
.    if !defined(XML.${_ID}) || empty(XML.${_ID})
XML.${_ID}=	${_ID}.xml
.    endif
.    if !defined(TARGET.${_ID}) || empty(TARGET.${_ID})
TARGET.${_ID}=	${_ID}.html
.    endif

XSLTPROCOPTS.${_ID}?=	${XSLTPROCOPTS}
GENDOCS+=       ${TARGET.${_ID}}
CLEANFILES+=    ${TARGET.${_ID}}

.    if ${XSLT.${_ID}} == docbook
XSLT.${_ID}=	http://www.NetBSD.org/XML/htdocs/lang/share/xsl/netbsd.xsl
DEPENDS.${_ID}+=	${WEB_PREFIX}/share/xsl/netbsd.xsl
.    elif ${XSLT.${_ID}} == docbook-website
XSLT.${_ID}=	http://www.NetBSD.org/XML/htdocs/lang/share/xsl/netbsd-webpage-${DOCLANG}.xsl
DEPENDS.${_ID}+=	${AUTOLAYOUTFILE}
DEPENDS.${_ID}+=	${WEB_PREFIX}/share/xsl/webpage.xsl
XSLTPROCOPTS.${_ID}+=	--stringparam autolayout-file ${AUTOLAYOUTFILE}
.    elif ${XSLT.${_ID}} == xsl
XSLT.${_ID}=	${_ID}.xsl
DEPENDS.${_ID}+=	${XSLT.${_ID}}
.    elif ${XSLT.${_ID}:Mhttp\://*} != ""
DEPENDS.${_ID}+=	${XSLT.${_ID}}
.    else
DEPENDS.${_ID}+=	${XSLT.${_ID}}
.    endif

.    if defined(SRCS.${_ID})
ERRORS+=	"[web.xml.mk] SRCS.${_ID} is obsolete and must be replaced with DEPENDS.${_ID}."
.    endif

DEPENDS.${_ID}+=	${WEB_PREFIX}/share/xsl/global.xsl
DEPENDS.${_ID}+=	${WEB_PREFIX}/share/xsl/portpage.xsl

${TARGET.${_ID}}: ${XML_INCLUDES} ${XML.${_ID}} ${DEPENDS.${_ID}}
	@${ECHO} "[xsltproc] ${XML.${_ID}} -> ${.TARGET}"
	${RUN} ulimit -d 800000 && ${XSLTPROC} ${XSLTPROCOPTS.${_ID}}	\
		-o ${.TARGET} ${PARAMS.${_ID}}				\
		${XSLT.${_ID}} ${XML.${_ID}}
#. if !defined(NO_TIDY)
#	-${TIDY} ${TIDYOPTS} ${.TARGET}
#. endif

VALIDATE_DOCS+=	VALIDATE.${_ID}
VALIDATE.${_ID}:
	@${ECHO} "==>[xmllint] ${XML.${_ID}}"
	${RUN} ${XMLLINT} ${XMLLINTOPTS} ${XML.${_ID}} 2>&1		\
	| ${SED} -e 's/^/ | /'
.  endfor
.endfor
